import {
  csv,
  select,
  scaleLinear,
  scaleSequential,
  scaleBand,
  interpolatePuRd,
  extent,
  axisLeft,
  axisBottom,
  max,
  mean,
  line,
} from 'd3';

const csvUrl = [
  'https://gist.githubusercontent.com/',
  'ayush-shinde/', // User
  '52513071afa2a2733367bccfc0fedcde/', // Id of the Gist
  'raw/5288169d221df85b554361eb59248259ae72dc92/', // commit
  'epl_players.csv', // File name
].join('');
const parseRow = (d) => {
  d.overall = +d.overall;
  d.pace = +d.pace;
  d.shooting = +d.shooting;
  d.passing = +d.passing;
  d.dribbling = +d.dribbling;
  d.physic = +d.physic;
  //  d.club_name = d.club_name;
  const playerName = d.short_name.split(' ');

  d.player_name =
    playerName[0] +
    (playerName.length > 1 ? '.' + playerName[1][0] : '');
  return d;
  //console.log(d.PLAYER);
};

const xValue = (d) => d.player_name;

const yValueOverall = (d) => d.overall;
const yValuePace = (d) => d.pace;
const yValueShooting = (d) => d.shooting;
const yValuePassing = (d) => d.passing;
const yValueDribbling = (d) => d.dribbling;
const yValueDefending = (d) => d.defending;
const yValuePhysic = (d) => d.physic;

const margin = {
  top: 70,
  right: 60,
  bottom: 50,
  left: 60,
};
const radius = 5;

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const data1 = data.filter(function (d) {
    return d.club_name == 'Manchester United';
  });
  const sortedData1 = data1.sort((a, b) =>
    d3.descending(a.overall, b.overall),
  );

  const ptsmean = mean(data1, (d) => d.overall);
  console.log(ptsmean);

  const x = scaleBand()
    .domain(data1.map((d) => d.player_name))
    .range([margin.left, width - margin.right]);

  const y = scaleLinear()
    .domain([0, max(data1, (d) => d.overall) + 2])
    .range([height - margin.bottom, margin.top]);

  const effColor = scaleSequential()
    .domain([1, 10])
    .interpolator(interpolatePuRd);

  const marks = data1.map((d) => ({
    x: x(xValue(d)),
    y: y(yValue(d)),
  }));

  svg
    .selectAll('rect')
    .data(data1)
    .enter()
    .append('rect')
    .attr('class', 'bar')
    .attr('width', (d) => 40)
    .attr('height', (d) => y(0) - y(yValue(d)))
    .attr('x', (d) => x(xValue(d)) + 5)
    .attr('y', (d) => y(yValue(d)))
    .attr('fill', 'steelblue')
    .append('title')
    .text((d) => d.short_name + ':' + d.overall);

  const lineGenerator = line()([
    [margin.left, y(ptsmean)],
    [width - margin.right, y(ptsmean)],
  ]);

  svg
    .append('path')
    .attr('d', lineGenerator)
    .attr('stroke', 'crimson')
    .attr('stroke-width', '2');

  svg
    .append('g')
    .attr('transform', `translate(${margin.left},0)`)
    .call(axisLeft(y));

  svg
    .append('g')
    .attr(
      'transform',
      `translate(0,${height - margin.bottom})`,
    )
    .call(axisBottom(x))
    .selectAll('text')
    .attr('transform', 'translate(-10,13)rotate(-45)');

  svg
    .append('text')
    .attr('font-family', 'Helvetica')
    .attr('font-size', 20)
    .attr('x', width - margin.right - 10)
    .attr('y', height - margin.bottom + 30)
    .text('Player');

  svg
    .append('text')
    .attr('font-family', 'Helvetica')
    .attr('font-size', 20)
    .attr('x', margin.left - 50)
    .attr('y', margin.top - 10)
    .text('Score');

  svg
    .append('text')
    .attr('font-family', 'Helvetica')
    .attr('x', width - margin.right - 50)
    .attr('y', y(ptsmean) - 10)
    .attr('fill', 'crimson')
    .text('Mean = ' + ptsmean.toFixed(2).toString());

  svg
    .append('text')
    .attr('font-family', 'Helvetica')
    .attr('font-size', 30)
    .attr('x', 260)
    .attr('y', margin.top - 20)
    .text('LAL NBA Player Scoring Bar Chart');
};
main();
